Forms
=====

.. contents::
    :depth: 2
    :local:

Forms
-----
.. autoclass:: dj_kaos_utils.forms.UnrequiredFieldsFormMixin
   :show-inheritance:


.. autofunction:: dj_kaos_utils.forms.unrequire_form

Fields
------
.. autoclass:: dj_kaos_utils.forms.ListTextWidget
   :show-inheritance:
